@@ -1,6 +1,5 @@
 from abstract_flask import *
-from ..hugpy_zerosearch_flask import hugpy_zerosearch_bp
-from ..hugpy_deepcoder_flask_app import hugpy_deepcoder_bp
+from ..hugpy_deepzero_flask_app import hugpy_deepzero_bp
 from ..hugpy_proxyvideo_flask_app import hugpy_proxyvideo_bp
 from ..hugpy_video_flask_app import hugpy_video_bp
 
@@ -8,8 +7,7 @@ from ..hugpy_video_flask_app import hugpy_video_bp
 
 
 bp_list = [
-    (hugpy_zerosearch_bp, "/hugpy"),
-    (hugpy_deepcoder_bp, "/hugpy"),
+    (hugpy_deepzero_bp, "/hugpy"),
     (hugpy_proxyvideo_bp, "/hugpy"),
     (hugpy_video_bp, "/hugpy"),
 ]
